@@ -6,6 +6,8 @@
 #' @importFrom stats median
 #' @importFrom stats sd
 #' @importFrom utils head
+#' @importFrom utils txtProgressBar
+#' @importFrom utils setTxtProgressBar
 NULL
  
 
@@ -128,58 +130,60 @@ colorRampPaletteAlpha <- function(colors, n=32, interpolate='linear') {
     return(cr)
 }
 
-## global varibles for dplyr (used only so that the check ignores it, it does not actually creates global variables)
+## global varibles for dplyr (used only so that the check ignores it,
+## it does not actually creates global variables)
 ## -------------------------
-if(getRversion() >= "2.15.1")  utils::globalVariables(c(".",
-                                                        "<<-",
-                                                        "txtProgressBar",
-                                                        "setTxtProgressBar",
-                                                        "mh.accept.info" ,
-                                                        "parameter" ,
-                                                        "Cluster" ,
-                                                        "Percentage.of.Iter..Cluster.was.active" ,
-                                                        "HPD.l" ,
-                                                        "HPD.u",
-                                                        "HPD.lower" ,
-                                                        "HPD.upper",
-                                                        "flag" ,
-                                                        "Parameter",
-                                                        "k",
-                                                        "j",
-                                                        "Mean",
-                                                        "Median",
-                                                        "True.Cluster.match",
-                                                        "True",
-                                                        "d",
-                                                        "values" ,
-                                                        "C",
-                                                        "sigma",
-                                                        "jnext",
-                                                        "covars",
-                                                        "X2.5."  ,
-                                                        "X97.5.",
-                                                        "SD",
-                                                        "dw",
-                                                        "dx",
-                                                        "term",
-                                                        "term.tau",
-                                                        "term.beta",
-                                                        "w",
-                                                        "Description",
-                                                        "E.beta.pred",
-                                                        "term.label",
-                                                        "Parameter.facet",
-                                                        "Parameter.label",
-                                                        "beta.label",
-                                                        "value",
-                                                        "nclusters",
-                                                        "tau.label",
-                                                        "w.label",
-                                                        "beta.exp",
-                                                        "beta.exp.values",
-                                                        "Parameter.tau",
-                                                        "beta.exp.values.tau",
-                                                        "True.beta",
-                                                        "tau.idx",
-                                                        "pk"
-                                                        ))
+if(getRversion() >= "2.15.1")  utils::globalVariables(
+                                          c(".",
+                                            "<<-",
+                                            ## "txtProgressBar",
+                                            ## "setTxtProgressBar",
+                                            "mh.accept.info" ,
+                                            "parameter" ,
+                                            "Cluster" ,
+                                            "Percentage.of.Iter..Cluster.was.active" ,
+                                            "HPD.l" ,
+                                            "HPD.u",
+                                            "HPD.lower" ,
+                                            "HPD.upper",
+                                            "flag" ,
+                                            "Parameter",
+                                            "k",
+                                            "j",
+                                            "Mean",
+                                            "Median",
+                                            "True.Cluster.match",
+                                            "True",
+                                            "d",
+                                            "values" ,
+                                            "C",
+                                            "sigma",
+                                            "jnext",
+                                            "covars",
+                                            "X2.5."  ,
+                                            "X97.5.",
+                                            "SD",
+                                            "dw",
+                                            "dx",
+                                            "term",
+                                            "term.tau",
+                                            "term.beta",
+                                            "w",
+                                            "Description",
+                                            "E.beta.pred",
+                                            "term.label",
+                                            "Parameter.facet",
+                                            "Parameter.label",
+                                            "beta.label",
+                                            "value",
+                                            "nclusters",
+                                            "tau.label",
+                                            "w.label",
+                                            "beta.exp",
+                                            "beta.exp.values",
+                                            "Parameter.tau",
+                                            "beta.exp.values.tau",
+                                            "True.beta",
+                                            "tau.idx",
+                                            "pk"
+                                            ))
